@@ -88,19 +88,6 @@ sub new_rec_history {
 }
 ### the end #################################################################
 
-#use Data::Dumper;
-sub prepare_record_to_be_saved($) {
-  my $hrecord = shift;
-  # make sure the history log does not grow too long
-  my $history = $hrecord->{history};
-  my $max = $RePEc::Index::Config::max_record_history_items;
-  if ( defined $max and 
-       scalar( @$history ) > $max ) {
-    $#$history = $max-1; # leave just the first $max items
-#    print "circumcized: ", Dumper( $history );
-  }
-}
-
 
 
 
@@ -139,7 +126,6 @@ sub event_record {
     $update -> requeue( $filename );
   }
 
-  prepare_record_to_be_saved( $hrecord );
   save_record_to_db_txn( $txn, $hdb, $id, $hrecord );
 
   my $r = commit_transaction( $txn );
@@ -625,7 +611,6 @@ sub event_record_disappear {
     clear_record( $hrecord, $id );
   }
 
-  prepare_record_to_be_saved( $hrecord );
   save_record_to_db_txn( $txn, $db, $id, $hrecord );
 
   my $ret = 1;
@@ -910,5 +895,11 @@ sub last_processed {
 
 __END__
 
+#############################################################################
+##  s u b   
+#############################################################################
+sub  {
+}
+### the end #################################################################
 
 
